@@ -56,6 +56,8 @@
        Keith Owens <kaos@ocs.com.au> November 2000.
      Add tainted module support.
        Keith Owens <kaos@ocs.com.au> September 2001.
+     Default to no exports for architectures with function descriptors.
+       Keith Owens <kaos@ocs.com.au> March 2003.
    */
 
 #include <sys/types.h>
@@ -86,7 +88,11 @@
 
 static int flag_force_load = 0;
 static int flag_silent_probe = 0;
+#ifdef HAS_FUNCTION_DESCRIPTORS
+static int flag_export = 0;
+#else
 static int flag_export = 1;
+#endif
 static int flag_load_map = 0;
 static int flag_ksymoops = 1;
 static int flag_numeric_only = 0;
@@ -642,9 +648,7 @@ static int create_module_ksymtab(struct obj_file *f)
 		for (i = 0; i < n_module_stat; ++i)
 			if (module_stat[i].status /* used */) {
 				dep->dep = module_stat[i].addr;
-#ifdef ARCH_ppc64
-				dep->dep |= ppc64_module_base (f);
-#endif
+				dep->dep |= arch_module_base (f);
 				obj_symbol_patch(f, sec->idx, (char *) &dep->ref - sec->contents, tm);
 				dep->next_ref = 0;
 				++dep;
@@ -1724,7 +1728,12 @@ int INSMOD_MAIN(int argc, char **argv)
 			flag_export = 0;
 			break;
 		case 'X':	/* do export externs */
+#ifdef HAS_FUNCTION_DESCRIPTORS
+			fputs("This architecture has function descriptors, exporting everything is unsafe\n"
+			      "You must explicitly export the desired symbols with EXPORT_SYMBOL()\n", stderr);
+#else
 			flag_export = 1;
+#endif
 			break;
 		case 'y':	/* do not define ksymoops symbols */
 			flag_ksymoops = 0;
@@ -2072,9 +2081,7 @@ int INSMOD_MAIN(int argc, char **argv)
 	} else {
 		errno = 0;
 		m_addr = create_module(m_name, m_size);
-#ifdef	ARCH_ppc64
-		m_addr |= ppc64_module_base (f);
-#endif
+		m_addr |= arch_module_base (f);
 		switch (errno) {
 		case 0:
 			break;
