@@ -355,12 +355,12 @@ hppa_rebuild_insn (insn, value, r_format)
    no issues related to symbol visibility, lazy linking, etc.
    The kernels dp is fixed (at symbol $global$), and we can fix up any
    DPREL refs in the module to use that same dp value.
-   All PCREL17F refs result in a stub with the following format:
+   All PCREL* refs result in a stub with the following format:
 
   	ldil L'func_addr,%r1
         be,n R'func_addr(%sr4,%r1)
 
-  Note, all PCREL17F get a stub, regardless of whether they are
+  Note, all PCREL* get a stub, regardless of whether they are
   local or external.  With local ones, and external ones to other
   modules, there is a good chance we could manage without the stub.
   I'll leave that for a future optimisation.
@@ -417,6 +417,7 @@ arch_create_got(struct obj_file *f)
 	      continue;
 
 	    case R_PARISC_PCREL17F:
+	    case R_PARISC_PCREL22F:
 	      need_stub = 1;
 	      break;
 	    }
@@ -496,6 +497,7 @@ arch_apply_relocation(struct obj_file *f,
     break;
 
   case R_PARISC_PCREL17F:
+  case R_PARISC_PCREL22F:
     /* Find an import stub. */
     assert(hsym->stub != NULL);
     assert(hfile->stub != NULL);
@@ -528,6 +530,7 @@ arch_apply_relocation(struct obj_file *f,
     case R_PARISC_PLABEL32:
     case R_PARISC_PCREL17F:
     case R_PARISC_SEGREL32:
+    case R_PARISC_PCREL22F:
       fsel = e_fsel;
       break;
 
@@ -582,6 +585,10 @@ arch_apply_relocation(struct obj_file *f,
       r_format = 14;
       break;
 
+    case R_PARISC_PCREL22F:
+      r_format = 22;
+      break;
+
     default:
       abort();
     }
