@@ -86,7 +86,6 @@ char *aliaslist[] =
 	"block-major-90 ide-probe-mod",
 	"block-major-91 ide-probe-mod",
 	"block-major-93 nftl",		/* from David Woodhouse <dwmw2@infradead.org> */
-	"block-major-97 pg",
 	"block-major-113 viocd",
 
 #if !defined(__s390__) && !defined(__s390x__)
@@ -142,6 +141,7 @@ char *aliaslist[] =
 	"char-major-63 kdebug",
 	"char-major-90 mtdchar",	/* from David Woodhouse <dwmw2@infradead.org> */
 	"char-major-96 pt",
+	"char-major-97 pg",
 	"char-major-99 ppdev",
 	"char-major-107 3dfx", /* from Tigran Aivazian <tigran@sco.COM> */
 	"char-major-108 ppp_generic",
